@@ -10,7 +10,7 @@ class Keys:
 		self.auth = keys.pop('auth_key', 0)
 		self.connection = keys.pop('connection_key', '')
 		self.identification = keys.pop('identification_keys', [])
-		self.msg = keys.pop('msg_keys', [])
+		self.msg = [k & 0xff for k in keys.pop('msg_keys', [])]
 		self.packet = keys.pop('packet_keys', [])
 		self.version = keys.pop('version', 0)
 		self.server_ip = keys.pop('ip', '51.75.130.180')
@@ -24,7 +24,7 @@ async def get_keys(tfm_id, token):
 	:param tfm_id: :class:`int` your Transformice user id.
 	:param token: :class:`str` your api token.
 	"""
-	url = 'https://api.tocu.tk/get_transformice_keys.php'
+	url = 'https://api.tocuto.tk/get_transformice_keys.php'
 	params = {'tfmid': tfm_id, 'token': token}
 	headers = {"User-Agent": f"Mozilla/5.0 aiotfm/{__version__}"}
 
@@ -51,4 +51,4 @@ async def get_keys(tfm_id, token):
 		message = 'An internal error occur: {}'.format(internal_error_step)
 		raise InternalError(message)
 
-	raise EndpointError("Can't get the keys. Error info: {}".format(error))
\ No newline at end of file
+	raise EndpointError("Can't get the keys. Error info: {}".format(error))
